-- wTaskNote.lua: Sep 2010

local AceConfig = LibStub("AceConfigDialog-3.0")

-- Localization, works in conjunction with the wowace.com website
local L = LibStub("AceLocale-3.0"):GetLocale("WTaskNote")

-- Create a basic AceAddon object to base everything off of
-- See: http://www.wowace.com/addons/ace3/pages/getting-started/
-- We mixin the AceConsole bit so that our addon can have slash commands
WTaskNote = LibStub("AceAddon-3.0"):NewAddon("WTaskNote", "AceConsole-3.0")

-- Use LDBIcon to do the minimap icon (similar to how Omen does it)
-- http://forums.wowace.com/showthread.php?t=15728
local LDBIcon = LibStub("LibDBIcon-1.0", true)

-- OnInitialize(), Called by AceAddon when the addon is first loaded by the 
-- game client.  We'll be restoring saved settings here.  See also:
-- http://www.wowace.com/addons/ace3/pages/api/ace-addon-3-0/
function WTaskNote:OnInitialize()
	-- Initialize our persistent storage database (using AceDB3)
	self.db = LibStub("AceDB-3.0"):New("WTaskNoteDB")
	
	-- Options
	LibStub("AceConfig-3.0"):RegisterOptionsTable("WTaskNote", wTaskNoteOptions, nil)
	self.options = LibStub("AceConfigDialog-3.0"):AddToBlizOptions("WTaskNote", L["wTaskNote"])
	
	-- For list of icons, see:
	-- http://www.wowwiki.com/WoWWiki:WoW_Icons/Icon_List/Images
	-- There are 17 different letter types (01-17): Interface\\Icons\\INV_Letter_##.blp
	-- There are 6 different note types (01-06): Interface\\Icons\\INV_Misc_Note_##.blp
	-- Note #3 has "1, 2, 3" on it, note #4 or #5 looks like a possible notes
	-- Also partial to envelope #3, #6, #9, #11 or #14
	self.dataObject = LibStub("LibDataBroker-1.1"):NewDataObject("WTaskNote", { 
		type = "data source",
		text = "General",
		icon = "Interface\\Icons\\INV_Letter_11.blp",
		OnClick = function (frame, button)
			if button == "RightButton" then
				self:ShowOptions()
			else
				self:ToggleWTaskNoteFrame()
			end
		end,
		OnTooltipShow = function(tt)
			tooltip:AddLine(WTaskNote.L["MinimapTooltip Title"])
			tooltip:AddLine(WTaskNote.L["MinimapTooltip LeftClick"])
			tooltip:AddLine(WTaskNote.L["MinimapTooltip RightClick"])
		end,
	})
	
	-- Minimap icon
	LDBIcon:Register("WTaskNote", self.dataObject, self.db.global.minimap)
	
end

-- OnEnable(), can be called multiple times per session by AceAddon if the 
-- user enables/disables your addon.  Gets called during the PLAYER_LOGIN event
function WTaskNote:OnEnable()
    
end

-- OnDisable(), can be called multiple times per session by AceAddon if the 
-- user enables/disables your addon.
function WTaskNote:OnDisable()
    
end

-- Shows the options panel
function WTaskNote:ShowOptions ()
	InterfaceOptionsFrame_OpenToCategory(self.options)
end

-- Show/Hide the note frame
function WTaskNote:ToggleWTaskNoteFrame ()
--	if WTaskNoteFrame:IsShown() then
--		HideUIPanel(WTaskNoteFrame)
--	else
--		ShowUIPanel(WTaskNoteFrame)
--	end
end

